@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2023 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -57,7 +57,7 @@ set_time_limit(0);
 
 /* we do not need so much memory */
 ini_set('memory_limit', '-1');
-ini_set('max_execution_time', '-1');
+ini_set('max_execution_time', '0');
 
 // default values
 $hostname   = gethostname();
