@@ -593,9 +593,16 @@ function host_export() {
 
 	if (cacti_sizeof($hosts)) {
 		$columns = array_keys($hosts[0]);
+
 		fputcsv($stdout, $columns);
 
 		foreach($hosts as $h) {
+			foreach(array_keys($h) as $hc) {
+				if ($h[$hc] != '' && (strpos($h[$hc], "\n") !== false || strpos($h[$hc], "\r") !== false)) {
+					$h[$hc] = str_replace(array("\n", "\r"), ' ', $h[$hc]);
+				}
+			}
+
 			fputcsv($stdout, $h);
 		}
 	}
