@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -108,9 +108,10 @@ function form_save() {
 	/* ==================================================== */
 
 	if (isset_request_var('save_component_template')) {
-		$save['id']   = get_nfilter_request_var('id');
-		$save['hash'] = get_hash_host_template(get_nfilter_request_var('id'));
-		$save['name'] = form_input_validate(get_nfilter_request_var('name'), 'name', '', false, 3);
+		$save['id']    = get_nfilter_request_var('id');
+		$save['hash']  = get_hash_host_template(get_nfilter_request_var('id'));
+		$save['name']  = form_input_validate(get_nfilter_request_var('name'), 'name', '', false, 3);
+		$save['class'] = form_input_validate(get_nfilter_request_var('class'), 'class', '', false, 3);
 
 		if (!is_error_message()) {
 			$host_template_id = sql_save($save, 'host_template');
@@ -126,49 +127,6 @@ function form_save() {
 	}
 }
 
-function duplicate_host_template($_host_template_id, $host_template_title) {
-	global $fields_host_template_edit;
-
-	$host_template              = db_fetch_row_prepared('SELECT * FROM host_template WHERE id = ?', array($_host_template_id));
-	$host_template_graphs       = db_fetch_assoc_prepared('SELECT * FROM host_template_graph WHERE host_template_id = ?', array($_host_template_id));
-	$host_template_data_queries = db_fetch_assoc_prepared('SELECT * FROM host_template_snmp_query WHERE host_template_id = ?', array($_host_template_id));
-
-	/* substitute the title variable */
-	$host_template['name'] = str_replace('<template_title>', $host_template['name'], $host_template_title);
-
-	/* create new entry: host_template */
-	$save['id']   = 0;
-	$save['hash'] = get_hash_host_template(0);
-
-	foreach ($fields_host_template_edit as $field => $array) {
-		if (!preg_match('/^hidden/', $array['method'])) {
-			$save[$field] = $host_template[$field];
-		}
-	}
-
-	$host_template_id = sql_save($save, 'host_template');
-
-	/* create new entry(s): host_template_graph */
-	if (cacti_sizeof($host_template_graphs)) {
-		foreach ($host_template_graphs as $host_template_graph) {
-			db_execute_prepared('INSERT INTO host_template_graph
-				(host_template_id,graph_template_id)
-				VALUES (?, ?)',
-				array($host_template_id, $host_template_graph['graph_template_id']));
-		}
-	}
-
-	/* create new entry(s): host_template_snmp_query */
-	if (cacti_sizeof($host_template_data_queries)) {
-		foreach ($host_template_data_queries as $host_template_data_query) {
-			db_execute_prepared('INSERT INTO host_template_snmp_query
-				(host_template_id,snmp_query_id)
-				VALUES (?, ?)',
-				array($host_template_id, $host_template_data_query['snmp_query_id']));
-		}
-	}
-}
-
 /* ------------------------
     The "actions" function
    ------------------------ */
@@ -222,7 +180,7 @@ function form_actions() {
 				db_execute('UPDATE host SET host_template_id = 0 WHERE deleted = "" AND ' . array_to_sql_or($selected_items, 'host_template_id'));
 			} elseif (get_nfilter_request_var('drp_action') == '2') { // duplicate
 				for ($i=0;($i<cacti_count($selected_items));$i++) {
-					duplicate_host_template($selected_items[$i], get_nfilter_request_var('title_format'));
+					api_duplicate_device_template($selected_items[$i], get_nfilter_request_var('title_format'));
 				}
 			} elseif (get_nfilter_request_var('drp_action') == '3') { // sync
 				for ($i=0;($i<cacti_count($selected_items));$i++) {
@@ -330,7 +288,10 @@ function template_item_remove_gt_confirm() {
 
 	html_start_box('', '100%', '', '3', 'center', '');
 
-	$template = db_fetch_row_prepared('SELECT * FROM graph_templates WHERE id = ?', array(get_request_var('id')));
+	$template = db_fetch_row_prepared('SELECT *
+		FROM graph_templates
+		WHERE id = ?',
+		array(get_request_var('id')));
 
 	?>
 	<tr>
@@ -662,7 +623,7 @@ function template_edit() {
 }
 
 function template() {
-	global $host_actions, $item_rows;
+	global $host_actions, $item_rows, $device_classes;
 
 	/* ================= input validation and session storage ================= */
 	$filters = array(
@@ -670,32 +631,44 @@ function template() {
 			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
-			),
+		),
 		'page' => array(
 			'filter' => FILTER_VALIDATE_INT,
 			'default' => '1'
-			),
+		),
 		'filter' => array(
 			'filter' => FILTER_DEFAULT,
 			'pageset' => true,
 			'default' => ''
-			),
+		),
+		'graph_template' => array(
+			'filter' => FILTER_DEFAULT,
+			'pageset' => true,
+			'default' => '-1'
+		),
+		'class' => array(
+			'filter' => FILTER_CALLBACK,
+			'default' => '-1',
+			'pageset' => true,
+			'sort'    => 'ASC',
+			'options' => array('options' => 'sanitize_search_string')
+		),
 		'sort_column' => array(
 			'filter' => FILTER_CALLBACK,
 			'default' => 'name',
 			'options' => array('options' => 'sanitize_search_string')
-			),
+		),
 		'sort_direction' => array(
 			'filter' => FILTER_CALLBACK,
 			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
-			),
+		),
 		'has_hosts' => array(
 			'filter' => FILTER_VALIDATE_REGEXP,
 			'options' => array('options' => array('regexp' => '(true|false)')),
 			'pageset' => true,
 			'default' => read_config_option('default_has') == 'on' ? 'true':'false'
-			)
+		)
 	);
 
 	validate_store_request_vars($filters, 'sess_ht');
@@ -713,6 +686,84 @@ function template() {
 	<tr class='even noprint'>
 		<td>
 		<form id='form_host_template' action='host_templates.php'>
+			<table class='filterTable'>
+				<tr>
+					<td>
+						<?php print __('Class');?>
+					</td>
+					<td>
+						<select id='class'>
+							<option value='-1'<?php print (get_request_var('class') == '-1' ? ' selected>':'>') . __('All');?></option>
+							<?php
+							if (cacti_sizeof($device_classes)) {
+								foreach ($device_classes as $key => $value) {
+									print "<option value='" . $key . "'"; if (get_request_var('class') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
+								}
+							}
+							?>
+						</select>
+					</td>
+					<td>
+						<?php print __('Graph Template');?>
+					</td>
+					<td>
+						<select id='graph_template'>
+							<option value='-1'<?php print (get_request_var('graph_template') == '-1' ? ' selected>':'>') . __('All');?></option>
+							<?php
+							if (get_request_var('class') == -1) {
+								$graph_templates = db_fetch_assoc('SELECT DISTINCT id, name
+									FROM (
+										SELECT gt.id, gt.name
+										FROM graph_templates AS gt
+										INNER JOIN host_template_graph AS htg
+										ON htg.graph_template_id = gt.id
+										UNION
+										SELECT gt.id, gt.name
+										FROM graph_templates AS gt
+										INNER JOIN snmp_query_graph AS sqg
+										ON gt.id = sqg.graph_template_id
+										INNER JOIN host_template_snmp_query AS htsq
+										ON sqg.snmp_query_id = htsq.snmp_query_id
+									) AS rs
+									ORDER BY name');
+							} else {
+								$graph_templates = db_fetch_assoc_prepared('SELECT DISTINCT ht.id, ht.name
+									FROM (
+										SELECT gt.id, gt.name, htg.host_template_id
+										FROM graph_templates AS gt
+										INNER JOIN host_template_graph AS htg
+										ON htg.graph_template_id = gt.id
+										UNION
+										SELECT gt.id, gt.name, htsq.host_template_id
+										FROM graph_templates AS gt
+										INNER JOIN snmp_query_graph AS sqg
+										ON gt.id = sqg.graph_template_id
+										INNER JOIN host_template_snmp_query AS htsq
+										ON sqg.snmp_query_id = htsq.snmp_query_id
+									) AS rs
+									INNER JOIN host_template AS ht
+									ON rs.host_template_id = ht.id
+									WHERE ht.id = ?
+									ORDER BY name',
+									array(get_request_var('class')));
+							}
+
+							if (cacti_sizeof($graph_templates)) {
+								foreach ($graph_templates as $row) {
+									print "<option value='" . $row['id'] . "'" . (get_request_var('graph_template') == $row['id'] ? ' selected ':'') . '>' . html_escape($row['name']) . '</option>';
+								}
+							}
+							?>
+						</select>
+					</td>
+					<td>
+						<span>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+						</span>
+					</td>
+				</tr>
+			</table>
 			<table class='filterTable'>
 				<tr>
 					<td>
@@ -725,7 +776,7 @@ function template() {
 						<?php print __('Device Templates');?>
 					</td>
 					<td>
-						<select id='rows' onChange='applyFilter()'>
+						<select id='rows'>
 							<option value='-1'<?php print (get_request_var('rows') == '-1' ? ' selected>':'>') . __('Default');?></option>
 							<?php
 							if (cacti_sizeof($item_rows)) {
@@ -742,12 +793,6 @@ function template() {
 							<label for='has_hosts'><?php print __('Has Devices');?></label>
 						</span>
 					</td>
-					<td>
-						<span>
-							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
-							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
-						</span>
-					</td>
 				</tr>
 			</table>
 		</form>
@@ -756,7 +801,9 @@ function template() {
 		function applyFilter() {
 			strURL  = 'host_templates.php?header=false';
 			strURL += '&filter='+$('#filter').val();
+			strURL += '&class='+$('#class').val();
 			strURL += '&rows='+$('#rows').val();
+			strURL += '&graph_template='+$('#graph_template').val();
 			strURL += '&has_hosts='+$('#has_hosts').is(':checked');
 			loadPageNoHeader(strURL);
 		}
@@ -767,6 +814,10 @@ function template() {
 		}
 
 		$(function() {
+			$('#graph_template, #class, #rows').change(function() {
+				applyFilter();
+			});
+
 			$('#refresh, #has_hosts').click(function() {
 				applyFilter();
 			});
@@ -787,14 +838,40 @@ function template() {
 	html_end_box();
 
 	/* form the 'where' clause for our main sql query */
+	$sql_where = '';
+	$sql_join  = '';
+
 	if (get_request_var('filter') != '') {
-		$sql_where = 'WHERE (host_template.name LIKE ' . db_qstr('%' . get_request_var('filter') . '%') . ')';
-	} else {
-		$sql_where = '';
+		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . '(ht.name LIKE ' . db_qstr('%' . get_request_var('filter') . '%') . ')';
+	}
+
+	if (get_request_var('class') != '-1') {
+		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . '(ht.class = ' . db_qstr(get_request_var('class')) . ')';
+	}
+
+	if (get_request_var('graph_template') != '-1') {
+		$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . '(gt_id = ' . get_request_var('graph_template') . ')';
+		$sql_join   = "INNER JOIN (
+			SELECT DISTINCT host_template_id, id AS gt_id
+			FROM (
+				SELECT htg.host_template_id, gt.id
+				FROM graph_templates AS gt
+				INNER JOIN host_template_graph AS htg
+				ON htg.graph_template_id = gt.id
+				UNION
+				SELECT htsq.host_template_id, gt.id
+				FROM graph_templates AS gt
+				INNER JOIN snmp_query_graph AS sqg
+				ON gt.id = sqg.graph_template_id
+				INNER JOIN host_template_snmp_query AS htsq
+				ON sqg.snmp_query_id = htsq.snmp_query_id
+			) AS rs
+		) AS htdata
+		ON htdata.host_template_id = ht.id";
 	}
 
 	if (get_request_var('has_hosts') == 'true') {
-		$sql_having = 'HAVING hosts>0';
+		$sql_having = 'HAVING hosts > 0';
 	} else {
 		$sql_having = '';
 	}
@@ -802,11 +879,13 @@ function template() {
 	$total_rows = db_fetch_cell("SELECT COUNT(`rows`)
 		FROM (
 			SELECT
-			COUNT(host_template.id) AS `rows`, COUNT(DISTINCT host.id) AS hosts
-			FROM host_template
-			LEFT JOIN host ON host.host_template_id=host_template.id
+			COUNT(ht.id) AS `rows`, COUNT(DISTINCT host.id) AS hosts
+			FROM host_template AS ht
+			$sql_join
+			LEFT JOIN host
+			ON host.host_template_id = ht.id
 			$sql_where
-			GROUP BY host_template.id
+			GROUP BY ht.id
 			$sql_having
 		) AS rs");
 
@@ -814,11 +893,13 @@ function template() {
 	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
 
 	$template_list = db_fetch_assoc("SELECT
-		host_template.id,host_template.name, COUNT(DISTINCT host.id) AS hosts
-		FROM host_template
-		LEFT JOIN host ON host.host_template_id=host_template.id
+		ht.id, ht.name, ht.class, COUNT(DISTINCT host.id) AS hosts
+		FROM host_template AS ht
+		$sql_join
+		LEFT JOIN host
+		ON host.host_template_id=ht.id
 		$sql_where
-		GROUP BY host_template.id
+		GROUP BY ht.id
 		$sql_having
 		$sql_order
 		$sql_limit");
@@ -830,7 +911,13 @@ function template() {
 			'sort' => 'ASC',
 			'tip' => __('The name of this Device Template.')
 		),
-		'host_template.id' => array(
+		'ht.class' => array(
+			'display' => __('Device Class'),
+			'align' => 'left',
+			'sort' => 'ASC',
+			'tip' => __('The Class of this Device Template.  The Class Name should be representative of it\'s function.')
+		),
+		'ht.id' => array(
 			'display' => __('ID'),
 			'align' => 'right',
 			'sort' => 'ASC',
@@ -871,6 +958,13 @@ function template() {
 
 			form_alternate_row('line' . $template['id'], true, $disabled);
 			form_selectable_cell(filter_value($template['name'], get_request_var('filter'), 'host_templates.php?action=edit&id=' . $template['id']), $template['id']);
+
+			if ($template['class'] != '') {
+				form_selectable_cell($device_classes[$template['class']], $template['id']);
+			} else {
+				form_selectable_cell(__('Unassigned'), $template['id']);
+			}
+
 			form_selectable_cell($template['id'], $template['id'], '', 'right');
 			form_selectable_cell($disabled ? __('No'):__('Yes'), $template['id'], '', 'right');
 			form_selectable_cell('<a class="linkEditMain" href="' . html_escape('host.php?reset=true&host_template_id=' . $template['id']) . '">' . number_format_i18n($template['hosts'], '-1') . '</a>', $template['id'], '', 'right');
