@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDtool-based Graphing Solution                     |
+ | Cacti: The Complete RRDTool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -22,47 +22,21 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_1_36() {
-	// Repair locales
-	$def_locale = repair_locale(read_config_option('i18n_default_language'));
-	set_config_option('i18n_default_language', $def_locale);
-
-	$users_to_update_results = db_install_fetch_assoc('SELECT *
-		FROM settings_user
-		WHERE name="user_language"');
-	$users_to_update = $users_to_update_results['data'];
-
-	if (cacti_sizeof($users_to_update)) {
-		foreach($users_to_update as $user) {
-			if (strpos($user['value'], '-') === false) {
-				$locale = repair_locale($user['value']);
-
-				db_install_execute('UPDATE settings_user
-					SET value = ?
-					WHERE user_id = ?
-					AND name = ?',
-					array($locale, $user['user_id'], $user['name']));
-			}
-		}
-	}
-
-	$groups_to_update_results = db_install_fetch_assoc('SELECT *
-		FROM settings_user_group
-		WHERE name="user_language"');
-	$groups_to_update = $groups_to_update_results['data'];
-
-	if (cacti_sizeof($groups_to_update)) {
-		foreach($groups_to_update as $group) {
-			if (strpos($group['value'], '-') === false) {
-				$locale = repair_locale($group['value']);
-
-				db_install_execute('UPDATE settings_user_group
-					SET value = ?
-					WHERE group_id = ?
-					AND name = ?',
-					array($locale, $group['group_id'], $group['name']));
-			}
-		}
-	}
+function upgrade_to_1_2_11() {
+	db_install_execute("CREATE TABLE IF NOT EXISTS `processes` (
+		`id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
+		`pid` int(10) unsigned NOT NULL DEFAULT 0,
+		`tasktype` varchar(20) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
+		`taskname` varchar(40) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
+		`taskid` int(10) unsigned NOT NULL DEFAULT 0,
+		`timeout` int(11) DEFAULT 300,
+		`started` timestamp NOT NULL DEFAULT current_timestamp(),
+		`last_update` timestamp NOT NULL DEFAULT '0000-00-00 00:00:00',
+		PRIMARY KEY (`pid`,`tasktype`,`taskname`,`taskid`),
+		KEY `tasktype` (`tasktype`),
+		KEY `pid` (`pid`),
+		KEY `id` (`id`))
+		ENGINE=MEMORY
+		COMMENT='Stores Process Status for Cacti Background Processes'");
 }
 
