@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2022 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -23,14 +23,21 @@
 */
 
 function clog_get_datasource_titles($local_data_ids) {
+	static $title_cache = null;
+
 	if (!is_array($local_data_ids)) {
 		$local_data_ids = array($local_data_ids);
 	}
 
 	$titles = array();
+
 	foreach ($local_data_ids as $local_data_id) {
 		if (!array_key_exists($local_data_id, $titles)) {
-			$titles[$local_data_id] = get_data_source_title($local_data_id);
+			if (!isset($title_cache[$local_data_id])) {
+				$title_cache[$local_data_id] = get_data_source_title($local_data_id);
+			}
+
+			$titles[$local_data_id] = $title_cache[$local_data_id];
 		}
 	}
 
@@ -161,6 +168,10 @@ function clog_view_logfile() {
 			'filter'  => FILTER_VALIDATE_INT,
 			'default' => '1'
 		),
+		'matches' => array(
+			'filter'  => FILTER_VALIDATE_INT,
+			'default' => '1'
+		),
 		'rfilter' => array(
 			'filter'  => FILTER_VALIDATE_IS_REGEX,
 			'default' => '',
@@ -251,7 +262,7 @@ function clog_view_logfile() {
 	$total_rows      = 0;
 	$number_of_lines = get_request_var('tail_lines') < 0 ? read_config_option('max_display_rows') : get_request_var('tail_lines');
 
-	$logcontents = tail_file($logfile, $number_of_lines, get_request_var('message_type'), get_request_var('rfilter'), $page_nr, $total_rows);
+	$logcontents = tail_file($logfile, $number_of_lines, get_request_var('message_type'), get_request_var('rfilter'), $page_nr, $total_rows, get_request_var('matches'));
 
 	if (get_request_var('reverse') == 1) {
 		$logcontents = array_reverse($logcontents);
@@ -417,7 +428,7 @@ function clog_get_logfiles() {
 				continue;
 			}
 
-			if (!empty($stderrlogbase) && strpos($logFile, $stderrLogBase) === 0){
+			if (!empty($stderrLogBase) && strpos($logFile, $stderrLogBase) === 0){
 				$stdErrFileArray[] = $logFile;
 			} else {
 				$stdLogFileArray[] = $logFile;
@@ -502,7 +513,7 @@ function filter($clogAdmin, $selectedFile) {
 						</select>
 					</td>
 					<td>
-						<?php print __('Tail Lines');?>
+						<?php print (get_request_var('reverse') == 1 ? __('Tail Lines'):__('Head Lines'));?>
 					</td>
 					<td>
 						<select id='tail_lines'>
@@ -565,7 +576,7 @@ function filter($clogAdmin, $selectedFile) {
 						</select>
 					</td>
 					<td>
-						<?php print __('Display Order');?>
+						<?php print __('Display');?>
 					</td>
 					<td>
 						<select id='reverse'>
@@ -596,6 +607,12 @@ function filter($clogAdmin, $selectedFile) {
 					<td>
 						<?php print __('Search');?>
 					</td>
+					<td>
+						<select id='matches'>
+							<option value='1'<?php if (get_request_var('matches') == '1') {?> selected<?php }?>><?php print __('Matches');?></option>
+							<option value='0'<?php if (get_request_var('matches') == '0') {?> selected<?php }?>><?php print __('Does Not Match');?></option>
+						</select>
+					</td>
 					<td>
 						<input type='text' class='ui-state-default ui-corner-all' id='rfilter' size='75' value='<?php print html_escape_request_var('rfilter');?>'>
 					</td>
@@ -605,7 +622,7 @@ function filter($clogAdmin, $selectedFile) {
 		<script type='text/javascript'>
 
 		$(function() {
-			$('#rfilter, #reverse, #refresh, #message_type, #filename, #tail_lines').unbind().change(function() {
+			$('#rfilter, #reverse, #refresh, #message_type, #filename, #tail_lines, #matches').unbind().change(function() {
 				applyFilter();
 			});
 
@@ -632,6 +649,7 @@ function filter($clogAdmin, $selectedFile) {
 				'?rfilter=' + base64_encode($('#rfilter').val())+
 				'&reverse='+$('#reverse').val()+
 				'&refresh='+$('#refresh').val()+
+				'&matches='+$('#matches').val()+
 				'&message_type='+$('#message_type').val()+
 				'&tail_lines='+$('#tail_lines').val()+
 				'&filename='+$('#filename').val()+
@@ -715,24 +733,31 @@ function clog_regex_parser($matches) {
 function clog_regex_device($matches) {
 	global $config;
 
+	static $host_cache = null;
+
+	if (!cacti_sizeof($host_cache)) {
+		$host_cache[0] = __('System Device');
+	}
+
 	$result = $matches[0];
 
-	$dev_ids = explode(',',str_replace(" ","",$matches[2]));
+	$dev_ids = explode(',', str_replace(' ', '', $matches[2]));
 	if (cacti_sizeof($dev_ids)) {
 		$result = '';
-		$hosts = db_fetch_assoc('SELECT id, description
-			FROM host
-			WHERE id in (' . implode(',',$dev_ids) . ')');
 
-		$hostDescriptions = array();
-		if (cacti_sizeof($hosts)) {
-			foreach ($hosts as $host) {
-				$hostDescriptions[$host['id']] = html_escape($host['description']);
+		foreach($dev_ids as $id) {
+			if (!isset($host_cache[$id])) {
+				$host_cache[$id] = db_fetch_cell_prepared('SELECT description
+        		    FROM host
+		            WHERE id = ?',
+					array($id));
 			}
-		}
 
-		foreach ($dev_ids as $host_id) {
-			$result .= $matches[1].'<a href=\'' . html_escape($config['url_path'] . 'host.php?action=edit&id=' . $host_id) . '\'>' . (isset($hostDescriptions[$host_id]) ? $hostDescriptions[$host_id]:$host_id) . '</a>' . $matches[3];
+			if ($id != 0) {
+				$result .= $matches[1] . '<a href=\'' . html_escape($config['url_path'] . 'host.php?action=edit&id=' . $id) . '\'>' . (isset($host_cache[$id]) ? html_escape($host_cache[$id]):$id) . '</a>' . $matches[3];
+			} else {
+				$result .= $matches[1] . (isset($host_cache[$id]) ? html_escape($host_cache[$id]):$id) . $matches[3];
+			}
 		}
 	}
 
@@ -742,26 +767,39 @@ function clog_regex_device($matches) {
 function clog_regex_datasource($matches) {
 	global $config;
 
+	static $gr_cache = null;
+
 	$result = $matches[0];
 
-	$ds_ids = explode(',',str_replace(" ","",$matches[2]));
-	if (cacti_sizeof($ds_ids)) {
-		$result = '';
+	$ds_ids = explode(',', str_replace(' ', '', $matches[2]));
 
-		$graph_rows = array_rekey(db_fetch_assoc('SELECT DISTINCT
-			gtg.local_graph_id AS id
-			FROM graph_templates_graph AS gtg
-			INNER JOIN graph_templates_item AS gti
-			ON gtg.local_graph_id=gti.local_graph_id
-			INNER JOIN data_template_rrd AS dtr
-			ON gti.task_item_id=dtr.id
-			WHERE gtg.local_graph_id>0
-			AND dtr.local_data_id IN (' . $matches[2] . ')'),'id','id');
+	if (cacti_sizeof($ds_ids)) {
+		$result     = '';
+		$graph_rows = array();
+		$ds_ids     = array_unique($ds_ids);
+
+		foreach($ds_ids as $ds) {
+			if (!isset($gr_cache[$ds])) {
+				$gr_cache[$ds] = array_rekey(
+					db_fetch_assoc_prepared('SELECT DISTINCT
+						gti.local_graph_id AS id
+						FROM graph_templates_item AS gti
+						INNER JOIN data_template_rrd AS dtr
+						ON gti.task_item_id=dtr.id
+						WHERE gti.local_graph_id > 0
+						AND dtr.local_data_id = ?',
+						array($ds)),
+					'id','id'
+				);
+			}
+
+			$graph_rows = array_merge($graph_rows, $gr_cache[$ds]);
+		}
 
 		$graph_results = '';
 		if (cacti_sizeof($graph_rows)) {
 			$graph_ids = implode(',',$graph_rows);
-			$graph_array = array( 0 => '', 1 => ' Graphs[', 2 => $graph_ids, 3 => ']');
+			$graph_array = array(0 => '', 1 => ' Graphs[', 2 => $graph_ids, 3 => ']');
 
 			$graph_results = clog_regex_graphs($graph_array);
 		}
@@ -769,7 +807,6 @@ function clog_regex_datasource($matches) {
 		$result .= $matches[1];
 		$i       = 0;
 
-		$ds_ids = array_unique($ds_ids);
 		$ds_titles = clog_get_datasource_titles($ds_ids);
 		if (!isset($ds_titles)) {
 			$ds_titles = array();
@@ -794,24 +831,25 @@ function clog_regex_datasource($matches) {
 function clog_regex_poller($matches) {
 	global $config;
 
+	static $poller_cache = null;
+
+	if (!cacti_sizeof($poller_cache)) {
+		$poller_cache = array_rekey(
+			db_fetch_assoc('SELECT id, name
+				FROM poller'),
+			'id', 'name'
+		);
+	}
+
 	$result = $matches[0];
 
-	$poller_ids = explode(',',str_replace(" ","",$matches[2]));
+	$poller_ids = explode(',', str_replace(' ', '', $matches[2]));
+
 	if (cacti_sizeof($poller_ids)) {
 		$result = '';
-		$pollers = db_fetch_assoc_prepared('SELECT id, name
-			FROM poller
-			WHERE id in (' . implode(',',$poller_ids) . ')');
-
-		$pollerDescriptions = array();
-		if (cacti_sizeof($pollers)) {
-			foreach ($pollers as $poller) {
-				$pollerDescriptions[$poller['id']] = html_escape($poller['name']);
-			}
-		}
 
 		foreach ($poller_ids as $poller_id) {
-			$result .= $matches[1].'<a href=\'' . html_escape($config['url_path'] . 'pollers.php?action=edit&id=' . $poller_id) . '\'>' . (isset($pollerDescriptions[$poller_id]) ? $pollerDescriptions[$poller_id]:$poller_id) . '</a>' . $matches[3];
+			$result .= $matches[1].'<a href=\'' . html_escape($config['url_path'] . 'pollers.php?action=edit&id=' . $poller_id) . '\'>' . (isset($poller_cache[$poller_id]) ? html_escape($poller_cache[$poller_id]):$poller_id) . '</a>' . $matches[3];
 		}
 	}
 
@@ -821,24 +859,25 @@ function clog_regex_poller($matches) {
 function clog_regex_dataquery($matches) {
 	global $config;
 
+	static $query_cache = null;
+
+	if (!cacti_sizeof($query_cache)) {
+		$query_cache = array_rekey(
+			db_fetch_assoc('SELECT id, name
+				FROM snmp_query'),
+			'id', 'name'
+		);
+	}
+
 	$result = $matches[0];
 
-	$query_ids = explode(',',str_replace(" ","",$matches[2]));
+	$query_ids = explode(',', str_replace(' ', '', $matches[2]));
+
 	if (cacti_sizeof($query_ids)) {
 		$result = '';
-		$querys = db_fetch_assoc('SELECT id, name
-			FROM snmp_query
-			WHERE id in (' . implode(',',$query_ids) . ')');
-
-		$queryDescriptions = array();
-		if (cacti_sizeof($querys)) {
-			foreach ($querys as $query) {
-				$queryDescriptions[$query['id']] = html_escape($query['name']);
-			}
-		}
 
 		foreach ($query_ids as $query_id) {
-			$result .= $matches[1].'<a href=\'' . html_escape($config['url_path'] . 'data_queries.php?action=edit&id=' . $query_id) . '\'>' . (isset($queryDescriptions[$query_id]) ? $queryDescriptions[$query_id]:$query_id) . '</a>' . $matches[3];
+			$result .= $matches[1] . '<a href=\'' . html_escape($config['url_path'] . 'data_queries.php?action=edit&id=' . $query_id) . '\'>' . (isset($query_cache[$query_id]) ? html_escape($query_cache[$query_id]):$query_id) . '</a>' . $matches[3];
 		}
 	}
 
@@ -854,6 +893,7 @@ function clog_regex_rra($matches) {
 	if (strlen($local_data_ids)) {
 		$datasource_array = array( 0 => '', 1 => ' DS[', 2 => $local_data_ids, 3 => ']');
 		$datasource_result = clog_regex_datasource($datasource_array);
+
 		if (strlen($datasource_result)) {
 			$result .= ' '. $datasource_result;
 		}
@@ -865,68 +905,65 @@ function clog_regex_rra($matches) {
 function clog_regex_graphs($matches) {
 	global $config;
 
+	static $graph_cache = null;
+
 	$result = $matches[0];
 
-	$query_ids = explode(',',str_replace(" ","",$matches[2]));
-	if (cacti_sizeof($query_ids)) {
+	$graph_ids = explode(',', str_replace(' ', '', $matches[2]));
+
+	if (cacti_sizeof($graph_ids)) {
 		$result = '';
 		$graph_add = $config['url_path'] . 'graph_view.php?page=1&style=selective&action=preview&graph_add=';
 
 		$title = '';
 		$i     = 0;
 
-		$querys = db_fetch_assoc('SELECT DISTINCT
-			gtg.local_graph_id AS id,
-			gtg.title_cache AS title
-			FROM graph_templates_graph AS gtg
-			INNER JOIN graph_templates_item AS gti
-			ON gtg.local_graph_id=gti.local_graph_id
-			INNER JOIN data_template_rrd AS dtr
-			ON gti.task_item_id=dtr.id
-			WHERE gtg.local_graph_id in (' . implode(',',$query_ids) . ')');
-
-		$result .= $matches[1] . "<a href='";
-
-		$queryDescriptions = array();
-		if (cacti_sizeof($querys)) {
-			foreach ($querys as $query) {
-				$queryDescriptions[$query['id']] = html_escape($query['title']);
+		foreach($graph_ids as $id) {
+			if (!isset($graph_cache[$id])) {
+				$graph_cache[$id] = db_fetch_cell_prepared('SELECT title_cache AS title
+					FROM graph_templates_graph AS gtg
+					WHERE local_graph_id = ?',
+					array($id));
 			}
 		}
 
-		$i=0;
-		foreach ($query_ids as $query_id) {
-			$graph_add .= ($i > 0 ? '%2C' : '') . $query_id;
-			$title     .= ($title != '' ? ', ':'') . html_escape((isset($queryDescriptions[$query_id]) ? $queryDescriptions[$query_id]:$query_id));
+		$result .= $matches[1] . "<a href='";
+
+		$i = 0;
+		foreach ($graph_ids as $id) {
+			$graph_add .= ($i > 0 ? '%2C' : '') . $id;
+			$title     .= ($title != '' ? ', ':'') . html_escape((isset($graph_cache[$id]) ? html_escape($graph_cache[$id]):$id));
 			$i++;
 		}
 
 		$result .= html_escape($graph_add) . '\'>' . $title . '</a>' . $matches[3];
 	}
+
 	return $result;
 }
 
 function clog_regex_graphtemplates($matches) {
 	global $config;
 
+	static $templates_cache = null;
+
+	if (!cacti_sizeof($templates_cache)) {
+		$templates_cache = array_rekey(
+			db_fetch_assoc('SELECT id, name
+				FROM graph_templates'),
+			'id', 'name'
+		);
+	}
+
 	$result = $matches[0];
 
-	$query_ids = explode(',',str_replace(" ","",$matches[2]));
-	if (cacti_sizeof($query_ids)) {
+	$ids = explode(',', str_replace(' ', '', $matches[2]));
+
+	if (cacti_sizeof($ids)) {
 		$result = '';
-		$querys = db_fetch_assoc('SELECT id, name
-			FROM graph_templates
-			WHERE id in ('  . implode(',',$query_ids) . ')');
 
-		$queryDescriptions = array();
-		if (cacti_sizeof($querys)) {
-			foreach ($querys as $query) {
-				$queryDescriptions[$query['id']] = html_escape($query['name']);
-			}
-		}
-
-		foreach ($query_ids as $query_id) {
-			$result .= $matches[1].'<a href=\'' . html_escape($config['url_path'] . 'graph_templates.php?action=template_edit&id=' . $query_id) . '\'>' . (isset($queryDescriptions[$query_id]) ? $queryDescriptions[$query_id]:$query_id) . '</a>' . $matches[3];
+		foreach ($ids as $id) {
+			$result .= $matches[1] . '<a href=\'' . html_escape($config['url_path'] . 'graph_templates.php?action=template_edit&id=' . $id) . '\'>' . (isset($templates_cache[$id]) ? html_escape($templates_cache[$id]):$id) . '</a>' . $matches[3];
 		}
 	}
 
@@ -936,58 +973,62 @@ function clog_regex_graphtemplates($matches) {
 function clog_regex_users($matches) {
 	global $config;
 
+	static $users_cache = null;
+
 	$result = $matches[0];
 
-	$query_ids = explode(',',str_replace(" ","",$matches[2]));
-	if (cacti_sizeof($query_ids)) {
+	$user_ids = explode(',', str_replace(' ', '', $matches[2]));
+
+	if (cacti_sizeof($user_ids)) {
 		$result = '';
 
-		$querys = db_fetch_assoc('SELECT DISTINCT
-			id, username
-			FROM user_auth
-			WHERE id in (' . implode(',',$query_ids) . ')');
-
-		$queryDescriptions = array();
-		if (cacti_sizeof($querys)) {
-			foreach ($querys as $query) {
-				$queryDescriptions[$query['id']] = html_escape($query['username']);
+		foreach($user_ids as $id) {
+			if (!isset($users_cache[$id])) {
+				$users_cache[$id] = db_fetch_cell_prepared('SELECT username
+					FROM user_auth
+					WHERE id = ?',
+					array($id));
 			}
 		}
 
-		foreach ($query_ids as $query_id) {
+		foreach ($user_ids as $id) {
 			$result .= $matches[1];
-			if (isset($queryDescriptions[$query_id])) {
-				$result .= '<a href=\'' . html_escape($config['url_path'] . 'user_admin.php?action=user_edit&tab=general&id=' . $query_id) . '\'>' . $queryDescriptions[$query_id] . '</a>';
+
+			if (isset($users_cache[$id])) {
+				$result .= '<a href=\'' . html_escape($config['url_path'] . 'user_admin.php?action=user_edit&tab=general&id=' . $id) . '\'>' . html_escape($users_cache[$id]) . '</a>';
 			} else {
-				$result .= $query_id;
+				$result .= $id;
 			}
+
 			$result .= $matches[3];
 		}
 	}
+
 	return $result;
 }
 
 function clog_regex_rule($matches) {
 	global $config;
 
+	static $rules_cache = null;
+
+	if (!cacti_sizeof($rules_cache)) {
+		$rules_cache = array_rekey(
+			db_fetch_assoc('SELECT id, name
+				FROM automation_graph_rules'),
+			'id', 'name'
+		);
+	}
+
 	$result = $matches[0];
 
-	$dev_ids = explode(',',str_replace(" ","",$matches[2]));
+	$dev_ids = explode(',', str_replace(' ', '', $matches[2]));
+
 	if (cacti_sizeof($dev_ids)) {
 		$result = '';
-		$rules = db_fetch_assoc('SELECT id, name
-			FROM automation_graph_rules
-			WHERE id in (' . implode(',',$dev_ids) . ')');
-
-		$ruleNames = array();
-		if (cacti_sizeof($rules)) {
-			foreach ($rules as $rule) {
-				$ruleNames[$rule['id']] = html_escape($rule['name']);
-			}
-		}
 
 		foreach ($dev_ids as $rule_id) {
-			$result .= $matches[1].'<a href=\'' . html_escape($config['url_path'] . 'automation_graph_rules.php?action=edit&id=' . $rule_id) . '\'>' . (isset($ruleNames[$rule_id]) ? $ruleNames[$rule_id]:$rule_id) . '</a>' . $matches[3];
+			$result .= $matches[1] . '<a href=\'' . html_escape($config['url_path'] . 'automation_graph_rules.php?action=edit&id=' . $rule_id) . '\'>' . (isset($rules_cache[$rule_id]) ? html_escape($rules_cache[$rule_id]):$rule_id) . '</a>' . $matches[3];
 		}
 	}
 
