@@ -39,6 +39,9 @@ class Net_Ping
 	var $precision;
 	var $time;
 	var $timer_start_time;
+	var $sqn;
+	var $avail_method;
+	var $ping_type;
 
 	function __construct() {
 		$this->port = 33439;
@@ -147,7 +150,7 @@ class Net_Ping
 
 				if (!$this->is_ipaddress($host_ip)) {
 					cacti_log('WARNING: ICMP Ping Error: cacti_gethostbyname failed for ' . $this->host['hostname']);
-					$this->response = 'ICMP Ping Error: cacti_gethostbyname failed for ' . $this->host['hostname'];
+					$this->ping_response = 'ICMP Ping Error: cacti_gethostbyname failed for ' . $this->host['hostname'];
 					return false;
 				}
 			}
@@ -208,7 +211,7 @@ class Net_Ping
 
 					return true;
 				} else {
-					$this->status = 'down';
+					$this->ping_status = 'down';
 					$this->ping_response = __('ICMP ping Timed out');
 
 					return false;
@@ -226,7 +229,7 @@ class Net_Ping
 
 					return true;
 				} else {
-					$this->status = 'down';
+					$this->ping_status = 'down';
 					$this->ping_response = __('ICMP ping Timed out');
 
 					return false;
@@ -356,7 +359,7 @@ class Net_Ping
 
 				if (!$this->is_ipaddress($host_ip)) {
 					cacti_log('WARNING: UDP Ping Error: cacti_gethostbyname failed for ' . $this->host['hostname']);
-					$this->response = 'UDP Ping Error: cacti_gethostbyname failed for ' . $this->host['hostname'];
+					$this->ping_response = 'UDP Ping Error: cacti_gethostbyname failed for ' . $this->host['hostname'];
 					$this->restore_cacti_error_handler();
 
 					return false;
@@ -398,7 +401,7 @@ class Net_Ping
 			$retry_count = 0;
 			while (true) {
 				if ($retry_count >= $this->retries) {
-					$this->status = 'down';
+					$this->ping_status = 'down';
 					$this->ping_response = __('UDP ping error: %s', $error);
 					$this->close_socket();
 					$this->restore_cacti_error_handler();
@@ -493,7 +496,7 @@ class Net_Ping
 
 				if (!$this->is_ipaddress($host_ip)) {
 					cacti_log('WARNING: TCP Ping Error: cacti_gethostbyname failed for ' . $this->host['hostname']);
-					$this->response = 'TCP Ping Error: cacti_gethostbyname failed for ' . $this->host['hostname'];
+					$this->ping_response = 'TCP Ping Error: cacti_gethostbyname failed for ' . $this->host['hostname'];
 					$this->restore_cacti_error_handler();
 
 					return false;
@@ -536,15 +539,26 @@ class Net_Ping
 				$errno = socket_last_error($this->socket);
 
 				if ($errno > 0) {
-					$this->ping_response = __('TCP ping: socket_connect(), reason: %s', socket_strerror($errno));
-					$this->ping_status   = 'down';
+					if ($errno == 111 && $this->ping_type == PING_TCP_CLOSED) {
+						$this->time = $this->get_time($this->precision);
+						$this->ping_status   = 'up';
+						$this->ping_response = __('TCP Ping Success Connection Refused (%s ms)', $this->time*1000);
+						$this->ping_status   = $this->time*1000;
+					} else {
+						$this->ping_response = __('TCP Ping Failed: socket_connect(), reason: %s', socket_strerror($errno));
+						$this->ping_status   = 'down';
+					}
 
 					socket_clear_error($this->socket);
 
 					$this->close_socket();
 					$this->restore_cacti_error_handler();
 
-					return false;
+					if ($this->ping_status == 'down') {
+						return false;
+					} else {
+						return true;
+					}
 				}
 
 				$r = array($this->socket);
@@ -554,7 +568,7 @@ class Net_Ping
 				$num_changed_sockets = socket_select($r, $w, $f, $to_sec, $to_usec);
 
 				if ($num_changed_sockets === false) {
-					$this->ping_response = __('TCP ping: socket_select() failed, reason: %s', socket_strerror(socket_last_error()));
+					$this->ping_response = __('TCP Ping Failed: socket_select() failed, reason: %s', socket_strerror(socket_last_error()));
 					$this->ping_status   = 'down';
 
 					$this->close_socket();
@@ -607,6 +621,7 @@ class Net_Ping
 
 		$this->ping_status   = 'down';
 		$this->ping_response = __('Ping not performed due to setting.');
+		$this->ping_type     = $ping_type;
 		$this->snmp_status   = 'down';
 		$this->snmp_response = 'SNMP not performed due to setting or ping result.';
 		$this->avail_method  = $avail_method;
@@ -651,7 +666,7 @@ class Net_Ping
 				$ping_result = $this->ping_icmp();
 			} elseif ($ping_type == PING_UDP) {
 				$ping_result = $this->ping_udp();
-			} elseif ($ping_type == PING_TCP) {
+			} elseif ($ping_type == PING_TCP || $ping_type == PING_TCP_CLOSED) {
 				$ping_result = $this->ping_tcp();
 			}
 		}
