@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2021 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -51,7 +51,7 @@ class spikekill {
 	var $percent   = '';
 	var $numspike  = '';
 
-	// Overrideable
+	// Overridable
 	var $html      = true;
 	var $backup    = false;
 	var $debug     = false;
@@ -261,7 +261,7 @@ class spikekill {
 			}
 
 			if (!is_numeric($this->outliers) || ($this->outliers < 1)) {
-				$this->set_error("FATAL: The number of outliers to exlude must be a positive integer.");
+				$this->set_error("FATAL: The number of outliers to exclude must be a positive integer.");
 			}
 
 			$this->out_set = true;
@@ -740,7 +740,15 @@ class spikekill {
 								$rra[$rra_num][$ds_num]['variance_avg'] = 'NAN';
 							} else {
 								$myds = $ds;
-								$myds = array_filter($myds, array($this, 'removeNanFromSamples'));
+
+								/* remove NaN entries from the data set */
+								if (cacti_sizeof($myds)) {
+									foreach($myds as $timestamp => $value) {
+										if (stripos($value, 'nan') !== false) {
+											unset($myds[$timestamp]);
+										}
+									}
+								}
 
 								/* remove high outliers */
 								rsort($myds, SORT_NUMERIC);
@@ -773,10 +781,6 @@ class spikekill {
 		}
 	}
 
-	private function removeNanFromSamples(&$string) {
-		return stripos($string, 'nan') === false;
-	}
-
 	private function calculateOverallStatistics(&$rra, &$samples) {
 		$rra_num = 0;
 		if (cacti_sizeof($rra)) {
@@ -853,7 +857,7 @@ class spikekill {
 									if (!empty($this->out_start) && $timestamp >= $this->out_start && $timestamp <= $this->out_end) {
 										/* Already calculated */
 									} elseif ($rra[$rra_num][$ds_num]['variance_avg'] == 'NAN') {
-										/* not enought samples to calculate */
+										/* not enough samples to calculate */
 									} elseif ($sample > ($rra[$rra_num][$ds_num]['variance_avg'] * (1+$this->percent))) {
 										if ($this->method == SPIKE_METHOD_VARIANCE) {
 											/* kill based upon variance */
@@ -1091,7 +1095,7 @@ class spikekill {
 							}
 						} else {
 							if ($this->method == SPIKE_METHOD_VARIANCE) {
-								if ($dsvalue > (1+$this->percent)*$rra[$rra_num][$ds_num]['variance_avg']) {
+								if ($dsvalue > (1+$this->percent)*(float)$rra[$rra_num][$ds_num]['variance_avg']) {
 									if ($kills < $this->numspike) {
 										if ($this->avgnan == 'avg') {
 											cacti_log("DEBUG: replacing dsvalue {$dsvalue} with variance_avg {$rra[$rra_num][$ds_num]['variance_avg']}", false, 'SPIKEKILL', POLLER_VERBOSITY_DEBUG);
@@ -1253,17 +1257,28 @@ class spikekill {
 	private function calculateStandardDeviation($items) {
 		if (!function_exists('stats_standard_deviation')) {
 			function stats_standard_deviation($items, $sample = false) {
-				$total_items = cacti_count($items);
 
-				if ($total_items === 0) {
+				$sum = 0;
+				$total_items = 0;
+
+				/* remove NaN entries from the data set */
+				if (cacti_sizeof($items)) {
+					foreach($items as $key => $value) {
+						if (is_int($value) || is_float($value)) {
+							$total_items++;
+							cacti_log(print_r($sum,true) . ":::" . print_r($value,true));
+							$sum += $value;
+						} else {
+							unset($items[$key]);
+						}
+					}
+				}
+				
+				if (($sample && $total_items === 1) || $total_items === 0) {
 					return false;
 				}
 
-				if ($sample && $total_items === 1) {
-					return false;
-				}
-
-				$mean  = array_sum($items) / $total_items;
+				$mean  = $sum / $total_items;
 				$carry = 0.0;
 
 				foreach ($items as $val) {
