@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2023 The Cacti Group                                 |
+ | Copyright (C) 2004-2024 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -424,9 +424,9 @@ function poller_host_duplicate($poller_id, $host) {
 	} else {
 		return db_fetch_cell_prepared('SELECT COUNT(*)
 			FROM poller
-			WHERE dbhost LIKE "' . $host . '%"
+			WHERE dbhost LIKE ?
 			AND id != ?',
-			array($poller_id));
+			array($host . '%', $poller_id));
 	}
 }
 
